//fragment biblioteki open-source kineticsJS rozwijanej przez Erica 
//Rowella - http://kineticsJS.com
// nieco zmieniono nazwy metod i właściwości, usunięto niektóre partie kodu.
var Events = function (canvasId) {
    this.canvas = document.getElementById(canvasId);
    this.context = this.canvas.getContext("2d");
    this.drawStage = undefined;
    this.listening = false;
    this.mousePos = null;
    this.mouseDown = false;
    this.mouseUp = false;
    this.mouseOver = false;
    this.mouseMove = false;
    this.currentShape = null;
    this.shapeIndex = 0;
    this.lastShapeIndex = -1;
    this.mouseOverShapeIndex = -1;
};
Events.prototype.getContext = function () {
    return this.context;
};
Events.prototype.getCanvas = function () {
    return this.canvas;
};
Events.prototype.clear = function () {
    this.context.clearRect(0, 0, this.canvas.width, this.canvas.height);
};
Events.prototype.getCanvasPos = function () {
    var obj = this.getCanvas();
    var top = 0;
    var left = 0;
    while (obj.tagName !== "BODY") {
        top += obj.offsetTop;
        left += obj.offsetLeft;
        obj = obj.offsetParent;
    }
    return {
        top: top,
        left: left
    };
};
Events.prototype.addStage = function (func) {
    this.drawStage = func;
    this.listen();
};
Events.prototype.reset = function (evt) {
    if (!evt) {
        evt = window.event;
    }
    this.setMousePosition(evt);
    this.shapeIndex = 0;
    if (!this.animating && this.drawStage !== undefined) {
        this.drawStage();
    }
    this.mouseOver = false;
    this.mouseMove = false;
    this.mouseDown = false;
    this.mouseUp = false;
};
Events.prototype.listen = function () {
    var that = this;
    if (this.drawStage !== undefined) {
        this.drawStage();
    }
    this.canvas.addEventListener("mousedown", function (evt) {
        that.mouseDown = true;
        that.reset(evt);
    }, false);
    this.canvas.addEventListener("mousemove", function (evt) {
        that.reset(evt);
    }, false);
    this.canvas.addEventListener("mouseup", function (evt) {
        that.mouseUp = true;
        that.reset(evt);
    }, false);
    this.canvas.addEventListener("mouseover", function (evt) {
        that.reset(evt);
    }, false);
    this.canvas.addEventListener("mouseout", function (evt) {
        that.mousePos = null;
    }, false);
};

Events.prototype.getMousePos = function (evt) {
    return this.mousePos;
};
Events.prototype.setMousePosition = function (evt) {
    var mouseX = evt.clientX - this.getCanvasPos().left + window.pageXOffset;
    var mouseY = evt.clientY - this.getCanvasPos().top + window.pageYOffset;
    this.mousePos = {
        x: mouseX,
        y: mouseY
    };
};
Events.prototype.beginShape = function () {
    this.currentShape = {};
    this.shapeIndex++;
};
Events.prototype.addShapeEventListener = function (type, func) {
    var event = 'on' + type;
    this.currentShape[event] = func;
};
Events.prototype.closeShape = function () {
    var pos = this.mousePos;
    if (pos !== null && this.context.isPointInPath(pos.x, pos.y)) {
        if (this.lastShapeIndex !== this.shapeIndex) {
            this.lastShapeIndex = this.shapeIndex;
        }
        if (this.mouseDown && this.currentShape.onmousedown !== undefined) {
            this.currentShape.onmousedown();
            this.mouseDown = false;
        } else if (this.mouseUp && this.currentShape.onmouseup !== undefined) {
            this.currentShape.onmouseup();
            this.mouseUp = false;
        } else if (!this.mouseOver && this.shapeIndex !== this.mouseOverShapeIndex
                && this.currentShape.onmouseover !== undefined) {
            this.currentShape.onmouseover();
            this.mouseOver = true;
            this.mouseOverShapeIndex = this.shapeIndex;
        } else if (!this.mouseMove && this.currentShape.onmousemove !== undefined) {
            this.currentShape.onmousemove();
            this.mouseMove = true;
        }
    } else if (this.shapeIndex === this.lastShapeIndex) {
        this.lastShapeIndex = -1;
        this.mouseOverShapeIndex = -1;
        if (this.currentShape.onmouseout !== undefined) {
            this.currentShape.onmouseout();
        }
    }
};
